package com.dino.scrum.sysmag.model;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import javax.persistence.*;
import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;

/**
 * Created by prgres on 2019-01-12.
 */

@Getter
@Setter
@ToString
@Entity
@Table(name = "Product")
public class Product {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    @Column(name = "id")
    private Long id;

    @NotNull(message = "name cannot be null")
    @Size(min = 2, message = "name cannot be shorter that 2")
    @Column(name = "name")
    private String name;

    @NotNull(message = "price cannot be null")
    @DecimalMin(value = "0.00", message = "price cannot be under 0.00")
    @Column(name = "price")
    private BigDecimal price;

    @NotNull(message = "quantity cannot be null")
    @Min(value = 0, message = "quantity cannot be under 0")
    @Column(name = "quantity")
    private Long quantity;

    @NotNull(message = "quantityMax cannot be null")
    @Min(value = 1, message = "quantityMax cannot be under 1")
    @Column(name = "quantityMax")
    private Long quantityMax;

    @NotNull(message = "image_link cannot be null")
    @Column(name = "image_link")
    private String imageLink;

    public Product setChangeQuantity(long change) {
        System.out.println("IN MODEL quantity: " + this.getQuantity() + " change" + change);
        this.quantity += change;
        System.out.println("IN MODEL after change quantity: " + this.getQuantity());
        return this;
    }

}
