package com.dino.scrum.sysmag.validator;

import com.dino.scrum.sysmag.repository.ProductRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * Created by prgres on 2019-01-22.
 */

@Component
public class ProductValidator {

    private final ProductRepository productRepository;

    @Autowired
    public ProductValidator(ProductRepository productRepository) {
        this.productRepository = productRepository;
    }

    private boolean existsById(long id) {
        return productRepository.existsById(id);
    }

    private boolean existsByName(String name) {
        return productRepository.existsByName(name);
    }

    private boolean ifRequestPageInLimit(int limit, int requestPage) {
        return requestPage < limit;
    }

    public void checkIfNotExists(long id) throws Exception {
        if (!existsById(id))
            throw new Exception("Product with id: " + id + " not found");
        System.out.println(id + " exists");
    }

    public void checkIfNotExists(String name) throws Exception {
        if (existsByName(name))
            throw new Exception("Product " + name + " already exists");
    }

    public void checkIfPageIsOutOfBound(int totalPages, int requestPage) throws Exception {
        if (ifRequestPageInLimit(requestPage, totalPages))
            throw new Exception("Page " + requestPage + " is out of the total pages number.");
    }
}
