package com.dino.scrum.sysmag.validator;

import com.dino.scrum.sysmag.model.Product;
import com.dino.scrum.sysmag.model.dto.QuantityChange;
import com.dino.scrum.sysmag.service.ProductServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * Created by prgres on 2019-01-20.
 */

@Component
public class QuantityChangeValidator {

    private final
    ProductServiceImpl productService;

    @Autowired
    public QuantityChangeValidator(ProductServiceImpl productService) {
        this.productService = productService;
    }

    public void validate(QuantityChange quantityChange) throws Exception {

        Product product = productService.getById(quantityChange.getId());

        if (ifUnderStock(product.getQuantity(), quantityChange.getChange())) {
            throw new RuntimeException("Too low product with id: " + quantityChange.getId() + " on stock");
        }

        if (ifAboveMaxLimitStock(product.getQuantity(), product.getQuantityMax(), quantityChange.getChange())) {
            throw new RuntimeException("Over max quantity limit of product with id: " + quantityChange.getId());
        }
    }

    private boolean ifUnderStock(long quantityOfProduct, long quantityChange) {
        return ((quantityOfProduct + quantityChange) < 0);
    }

    private boolean ifAboveMaxLimitStock(long quantityOfProduct, long maxQuantityOfProduct, long quantityChange) {
        return ((quantityOfProduct + quantityChange) > maxQuantityOfProduct);
    }
}